import os
import openpyxl

# Get the path to the input_data folder in the same directory as the script
input_folder = os.path.join(os.path.dirname(__file__), "input_data")

# Create a new workbook
workbook = openpyxl.Workbook()

# Initialize the maximum number of values to 0
max_values = 0

# Loop over each file in the input_data folder
for filename in os.listdir(input_folder):
    # Check if the file is a text file
    if filename.endswith(".txt"):
        # Read the values from the file and update the maximum number of values
        with open(os.path.join(input_folder, filename), "r") as file:
            lines = file.readlines()
            for line in lines:
                values = line.strip().split(" ")
                if len(values) > max_values:
                    max_values = len(values)

        # Extract the desired sheet name from the file name
        sheet_name_parts = filename[:-4].split("_")
        sheet_name_parts = [part for part in sheet_name_parts if part not in ["FreqItemsetsData", "sorted"]]
        sheet_name = "_".join(sheet_name_parts[1:-1]).replace("_UA2018", "")

        # Create a new sheet with the desired name
        sheet = workbook.create_sheet(title=sheet_name)

        # Add the header row to the sheet
        header = ["% Podpora", "Abs. Podpora", "Landuse1"]
        for i in range(4, max_values):
            header.append("Landuse{}".format(i-2))
        sheet.append(header)

        # Read the values from the file and add them to the sheet
        with open(os.path.join(input_folder, filename), "r") as file:
            lines = file.readlines()
            for line in lines:
                values = line.strip().split(" ")
                # Remove the prefixes from the first two values
                values[0] = values[0][2:]
                values[1] = values[1][5:]
                # Convert the values to integers
                values = [int(value) if value.isdigit() else value for value in values]
                sheet.append(values)

# Save the workbook to disk
workbook.save("output.xlsx")
